@@ -2,11 +2,14 @@
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2021, Cisco Systems
-# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSE or
+# https://www.gnu.org/licenses/gpl-3.0.txt)
+
+from __future__ import absolute_import, division, print_function
 
-from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 from ansible.plugins.action import ActionBase
+
 try:
     from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
         AnsibleArgSpecValidator,
@@ -24,9 +27,11 @@ from ansible_collections.cisco.dnac.plugins.plugin_utils.dnac import (
 # Get common arguements specification
 argument_spec = dnac_argument_spec()
 # Add arguments specific for this module
-argument_spec.update(dict(
-    deviceId=dict(type="list"),
-))
+argument_spec.update(
+    dict(
+        deviceId=dict(type="list"),
+    )
+)
 
 required_if = []
 required_one_of = []
@@ -37,7 +42,9 @@ required_together = []
 class ActionModule(ActionBase):
     def __init__(self, *args, **kwargs):
         if not ANSIBLE_UTILS_IS_INSTALLED:
-            raise AnsibleActionFail("ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'")
+            raise AnsibleActionFail(
+                "ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'"
+            )
         super(ActionModule, self).__init__(*args, **kwargs)
         self._supports_async = False
         self._supports_check_mode = False
@@ -77,7 +84,7 @@ class ActionModule(ActionBase):
 
         response = dnac.exec(
             family="configuration_archive",
-            function='commit_device_configuration',
+            function="commit_device_configuration",
             op_modifies=True,
             params=self.get_object(self._task.args),
         )
