@@ -2,11 +2,14 @@
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2021, Cisco Systems
-# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSE or
+# https://www.gnu.org/licenses/gpl-3.0.txt)
+
+from __future__ import absolute_import, division, print_function
 
-from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 from ansible.plugins.action import ActionBase
+
 try:
     from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
         AnsibleArgSpecValidator,
@@ -29,16 +32,17 @@ from ansible_collections.cisco.dnac.plugins.plugin_utils.exceptions import (
 # Get common arguments specification
 argument_spec = dnac_argument_spec()
 # Add arguments specific for this module
-argument_spec.update(dict(
-    state=dict(type="str", default="present", choices=["present", "absent"]),
-    transitPeerNetworkName=dict(type="str"),
-    transitPeerNetworkType=dict(type="str"),
-    ipTransitSettings=dict(type="dict"),
-    sdaTransitSettings=dict(type="dict"),
-))
+argument_spec.update(
+    dict(
+        state=dict(type="str", default="present", choices=["present", "absent"]),
+        transitPeerNetworkName=dict(type="str"),
+        transitPeerNetworkType=dict(type="str"),
+        ipTransitSettings=dict(type="dict"),
+        sdaTransitSettings=dict(type="dict"),
+    )
+)
 
-required_if = [
-]
+required_if = []
 required_one_of = []
 mutually_exclusive = []
 required_together = []
@@ -57,21 +61,32 @@ class TransitPeerNetwork(object):
 
     def get_all_params(self, name=None, id=None):
         new_object_params = {}
-        new_object_params['transit_peer_network_name'] = self.new_object.get('transitPeerNetworkName') or \
-            self.new_object.get('transit_peer_network_name')
+        new_object_params["transit_peer_network_name"] = self.new_object.get(
+            "transitPeerNetworkName"
+        ) or self.new_object.get("transit_peer_network_name")
         return new_object_params
 
     def create_params(self):
         new_object_params = {}
-        new_object_params['transitPeerNetworkName'] = self.new_object.get('transitPeerNetworkName')
-        new_object_params['transitPeerNetworkType'] = self.new_object.get('transitPeerNetworkType')
-        new_object_params['ipTransitSettings'] = self.new_object.get('ipTransitSettings')
-        new_object_params['sdaTransitSettings'] = self.new_object.get('sdaTransitSettings')
+        new_object_params["transitPeerNetworkName"] = self.new_object.get(
+            "transitPeerNetworkName"
+        )
+        new_object_params["transitPeerNetworkType"] = self.new_object.get(
+            "transitPeerNetworkType"
+        )
+        new_object_params["ipTransitSettings"] = self.new_object.get(
+            "ipTransitSettings"
+        )
+        new_object_params["sdaTransitSettings"] = self.new_object.get(
+            "sdaTransitSettings"
+        )
         return new_object_params
 
     def delete_all_params(self):
         new_object_params = {}
-        new_object_params['transit_peer_network_name'] = self.new_object.get('transit_peer_network_name')
+        new_object_params["transit_peer_network_name"] = self.new_object.get(
+            "transit_peer_network_name"
+        )
         return new_object_params
 
     def get_object_by_name(self, name):
@@ -84,9 +99,9 @@ class TransitPeerNetwork(object):
                 params=self.get_all_params(name=name),
             )
             if isinstance(items, dict):
-                if 'response' in items:
-                    items = items.get('response')
-            result = get_dict_result(items, 'name', name)
+                if "response" in items:
+                    items = items.get("response")
+            result = get_dict_result(items, "name", name)
         except Exception:
             result = None
         return result
@@ -101,7 +116,7 @@ class TransitPeerNetwork(object):
         id_exists = False
         name_exists = False
         o_id = self.new_object.get("id")
-        name = self.new_object.get("transitPeerNetworkName")
+        name = self.new_object.get("name")
         if o_id:
             prev_obj = self.get_object_by_id(o_id)
             id_exists = prev_obj is not None and isinstance(prev_obj, dict)
@@ -111,7 +126,9 @@ class TransitPeerNetwork(object):
         if name_exists:
             _id = prev_obj.get("id")
             if id_exists and name_exists and o_id != _id:
-                raise InconsistentParameters("The 'id' and 'name' params don't refer to the same object")
+                raise InconsistentParameters(
+                    "The 'id' and 'name' params don't refer to the same object"
+                )
             if _id:
                 self.new_object.update(dict(id=_id))
         it_exists = prev_obj is not None and isinstance(prev_obj, dict)
@@ -129,9 +146,12 @@ class TransitPeerNetwork(object):
         ]
         # Method 1. Params present in request (Ansible) obj are the same as the current (ISE) params
         # If any does not have eq params, it requires update
-        return any(not dnac_compare_equality(current_obj.get(dnac_param),
-                                             requested_obj.get(ansible_param))
-                   for (dnac_param, ansible_param) in obj_params)
+        return any(
+            not dnac_compare_equality(
+                current_obj.get(dnac_param), requested_obj.get(ansible_param)
+            )
+            for (dnac_param, ansible_param) in obj_params
+        )
 
     def create(self):
         result = self.dnac.exec(
@@ -157,7 +177,9 @@ class TransitPeerNetwork(object):
 class ActionModule(ActionBase):
     def __init__(self, *args, **kwargs):
         if not ANSIBLE_UTILS_IS_INSTALLED:
-            raise AnsibleActionFail("ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'")
+            raise AnsibleActionFail(
+                "ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'"
+            )
         super(ActionModule, self).__init__(*args, **kwargs)
         self._supports_async = False
         self._supports_check_mode = False
