@@ -7,10 +7,11 @@
 DOCUMENTATION = r"""
 ---
 module: device_interface_ospf_info
-short_description: Information module for Device Interface Ospf
+short_description: Information module for Device Interface
+  Ospf
 description:
-- Get all Device Interface Ospf.
-- Returns the interfaces that has OSPF enabled.
+  - Get all Device Interface Ospf.
+  - Returns the interfaces that has OSPF enabled.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -20,22 +21,23 @@ options:
     description: Additional headers.
     type: dict
 requirements:
-- dnacentersdk >= 2.7.1
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Devices GetOSPFInterfaces
-  description: Complete reference of the GetOSPFInterfaces API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-ospf-interfaces
+  - name: Cisco DNA Center documentation for Devices
+      GetOSPFInterfaces
+    description: Complete reference of the GetOSPFInterfaces
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-ospf-interfaces
 notes:
   - SDK Method used are
     devices.Devices.get_ospf_interfaces,
-
   - Paths used are
     get /dna/intent/api/v1/interface/ospf,
-
 """
 
 EXAMPLES = r"""
+---
 - name: Get all Device Interface Ospf
   cisco.dnac.device_interface_ospf_info:
     dnac_host: "{{dnac_host}}"
@@ -47,7 +49,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     headers: "{{my_headers | from_json}}"
   register: result
-
 """
 RETURN = r"""
 dnac_response:
