@@ -1,13 +1,20 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: wireless_profiles_id_site_tags_count_info
-short_description: Information module for Wireless Profiles Id Site Tags Count Info
+short_description: Information module for Wireless Profiles
+  Id Site Tags Count
 description:
-  - This module represents an alias of the module wireless_profiles_id_site_tags_count_v1_info
+  - Get all Wireless Profiles Id Site Tags Count. -
+    > This endpoint retrieves the total count of `Site
+    Tags` associated with a specific `Wireless Profile`.This
+    API requires the `id` of the `Wireless Profile`
+    to be provided as a path parameter.
 version_added: '6.17.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,21 +28,24 @@ options:
       - Id path parameter. Wireless profile id.
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Wireless RetrieveTheCountOfSiteTagsForAWirelessProfileV1
-    description: Complete reference of the RetrieveTheCountOfSiteTagsForAWirelessProfileV1
+  - name: Cisco DNA Center documentation for Wireless
+      RetrieveTheCountOfSiteTagsForAWirelessProfile
+    description: Complete reference of the RetrieveTheCountOfSiteTagsForAWirelessProfile
       API.
-    link:
-      https://developer.cisco.com/docs/dna-center/#!retrieve-the-count-of-site-tags-for-a-wireless-profile
+    link: https://developer.cisco.com/docs/dna-center/#!retrieve-the-count-of-site-tags-for-a-wireless-profile
 notes:
-  - SDK Method used are wireless.Wireless.retrieve_the_count_of_site_tags_for_a_wireless_profile_v1,
-  - Paths used are get /dna/intent/api/v1/wirelessProfiles/{id}/siteTags/count,
-  - It should be noted that this module is an alias of wireless_profiles_id_site_tags_count_v1_info
+  - SDK Method used are
+    wireless.Wireless.retrieve_the_count_of_site_tags_for_a_wireless_profile,
+  - Paths used are
+    get /dna/intent/api/v1/wirelessProfiles/{id}/siteTags/count,
 """
+
 EXAMPLES = r"""
-- name: Get all Wireless Profiles Id Site Tags Count Info
+---
+- name: Get all Wireless Profiles Id Site Tags Count
   cisco.dnac.wireless_profiles_id_site_tags_count_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
