@@ -11,7 +11,6 @@ __metaclass__ = type
 
 
 import pytest
-from ansible_collections.community.dns.plugins.modules import nameserver_record_info
 from ansible_collections.community.internal_test_tools.tests.unit.compat.mock import (
     MagicMock,
     patch,
@@ -23,6 +22,8 @@ from ansible_collections.community.internal_test_tools.tests.unit.plugins.module
     set_module_args,
 )
 
+from ansible_collections.community.dns.plugins.modules import nameserver_record_info
+
 from ..module_utils.resolver_helper import (
     create_mock_answer,
     create_mock_response,
@@ -180,11 +181,11 @@ class TestNameserverRecordInfo(ModuleTestCase):
             with patch('dns.resolver.Resolver', resolver):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with pytest.raises(AnsibleExitJson) as exc:
-                        set_module_args({
+                        with set_module_args({
                             'name': ['www.example.com'],
                             'type': 'TXT',
-                        })
-                        nameserver_record_info.main()
+                        }):
+                            nameserver_record_info.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['changed'] is False
@@ -198,6 +199,12 @@ class TestNameserverRecordInfo(ModuleTestCase):
                 'value': 'asdf',
             }
         ]
+        assert exc.value.args[0]['results'][0]['result'][0]['entries'] == [
+            {
+                'strings': ['asdf'],
+                'value': 'asdf',
+            }
+        ]
         assert exc.value.args[0]['results'][0]['result'][1]['nameserver'] == 'ns.example.org'
         assert exc.value.args[0]['results'][0]['result'][1]['values'] == [
             {
@@ -209,6 +216,16 @@ class TestNameserverRecordInfo(ModuleTestCase):
                 'value': 'fdsa',
             },
         ]
+        assert exc.value.args[0]['results'][0]['result'][1]['entries'] == [
+            {
+                'strings': ['asdf'],
+                'value': 'asdf',
+            },
+            {
+                'strings': ['fdsa'],
+                'value': 'fdsa',
+            },
+        ]
 
     def test_timeout(self):
         fake_query = MagicMock()
@@ -321,13 +338,13 @@ class TestNameserverRecordInfo(ModuleTestCase):
             with patch('dns.resolver.Resolver', resolver):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with pytest.raises(AnsibleFailJson) as exc:
-                        set_module_args({
+                        with set_module_args({
                             'name': ['www.example.com', 'mail.example.com'],
                             'type': 'TXT',
                             'query_timeout': 9,
                             'query_retry': 1,
-                        })
-                        nameserver_record_info.main()
+                        }):
+                            nameserver_record_info.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['msg'] in (
@@ -345,6 +362,12 @@ class TestNameserverRecordInfo(ModuleTestCase):
                         'value': 'fdsaasdf',
                     }
                 ],
+                'entries': [
+                    {
+                        'strings': ['fdsa', 'asdf'],
+                        'value': 'fdsaasdf',
+                    }
+                ],
             }
         ]
         assert exc.value.args[0]['results'][1]['name'] == 'mail.example.com'
@@ -420,11 +443,11 @@ class TestNameserverRecordInfo(ModuleTestCase):
             with patch('dns.resolver.Resolver', resolver):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with pytest.raises(AnsibleExitJson) as exc:
-                        set_module_args({
+                        with set_module_args({
                             'name': ['www.example.com'],
                             'type': 'TXT',
-                        })
-                        nameserver_record_info.main()
+                        }):
+                            nameserver_record_info.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['changed'] is False
@@ -433,6 +456,7 @@ class TestNameserverRecordInfo(ModuleTestCase):
         assert len(exc.value.args[0]['results'][0]['result']) == 1
         assert exc.value.args[0]['results'][0]['result'][0]['nameserver'] == 'ns.example.com'
         assert exc.value.args[0]['results'][0]['result'][0]['values'] == []
+        assert exc.value.args[0]['results'][0]['result'][0]['entries'] == []
 
     def test_no_answer(self):
         fake_query = MagicMock()
@@ -506,11 +530,11 @@ class TestNameserverRecordInfo(ModuleTestCase):
             with patch('dns.resolver.Resolver', resolver):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with pytest.raises(AnsibleExitJson) as exc:
-                        set_module_args({
+                        with set_module_args({
                             'name': ['www.example.com'],
                             'type': 'TXT',
-                        })
-                        nameserver_record_info.main()
+                        }):
+                            nameserver_record_info.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['changed'] is False
@@ -519,6 +543,7 @@ class TestNameserverRecordInfo(ModuleTestCase):
         assert len(exc.value.args[0]['results'][0]['result']) == 1
         assert exc.value.args[0]['results'][0]['result'][0]['nameserver'] == 'ns.example.com'
         assert exc.value.args[0]['results'][0]['result'][0]['values'] == []
+        assert exc.value.args[0]['results'][0]['result'][0]['entries'] == []
 
     def test_servfail(self):
         resolver = mock_resolver(['1.1.1.1'], {})
@@ -537,11 +562,11 @@ class TestNameserverRecordInfo(ModuleTestCase):
             with patch('dns.resolver.Resolver', resolver):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with pytest.raises(AnsibleFailJson) as exc:
-                        set_module_args({
+                        with set_module_args({
                             'name': ['www.example.com'],
                             'type': 'TXT',
-                        })
-                        nameserver_record_info.main()
+                        }):
+                            nameserver_record_info.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['msg'] == 'Unexpected resolving error: Error SERVFAIL while querying 1.1.1.1 with query get NS for "com."'
@@ -667,11 +692,11 @@ class TestNameserverRecordInfo(ModuleTestCase):
             with patch('dns.resolver.Resolver', resolver):
                 with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                     with pytest.raises(AnsibleFailJson) as exc:
-                        set_module_args({
+                        with set_module_args({
                             'name': ['www.example.com'],
                             'type': 'TXT',
-                        })
-                        nameserver_record_info.main()
+                        }):
+                            nameserver_record_info.main()
 
         print(exc.value.args[0])
         assert exc.value.args[0]['msg'] == 'Unexpected resolving error: Found CNAME loop starting at www.example.com'
