@@ -1,12 +1,10 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 
 # Copyright Ansible Project
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 
 DOCUMENTATION = r"""
@@ -14,6 +12,7 @@ module: github_key
 short_description: Manage GitHub access keys
 description:
   - Creates, removes, or updates GitHub access keys.
+  - Works with both GitHub.com and GitHub Enterprise Server installations.
 extends_documentation_fragment:
   - community.general.attributes
 attributes:
@@ -44,10 +43,16 @@ options:
     type: str
   force:
     description:
-      - The default is V(true), which will replace the existing remote key if it is different than O(pubkey). If V(false),
-        the key will only be set if no key with the given O(name) exists.
+      - The default is V(true), which replaces the existing remote key if it is different than O(pubkey). If V(false), the
+        key is only set if no key with the given O(name) exists.
     type: bool
     default: true
+  api_url:
+    description:
+      - URL to the GitHub API if not using github.com but your own GitHub Enterprise instance.
+    type: str
+    default: 'https://api.github.com'
+    version_added: "11.0.0"
 
 author: Robert Estelle (@erydo)
 """
@@ -113,6 +118,14 @@ EXAMPLES = r"""
     name: Access Key for Some Machine
     token: '{{ github_access_token }}'
     pubkey: "{{ lookup('ansible.builtin.file', '/home/foo/.ssh/id_rsa.pub') }}"
+
+# GitHub Enterprise Server usage
+- name: Authorize key with GitHub Enterprise
+  community.general.github_key:
+    name: Access Key for Some Machine
+    token: '{{ github_enterprise_token }}'
+    pubkey: "{{ lookup('ansible.builtin.file', '/home/foo/.ssh/id_rsa.pub') }}"
+    api_url: 'https://github.company.com/api/v3'
 """
 
 import datetime
@@ -127,10 +140,7 @@ from ansible_collections.community.general.plugins.module_utils.datetime import
 )
 
 
-API_BASE = 'https://api.github.com'
-
-
-class GitHubResponse(object):
+class GitHubResponse:
     def __init__(self, response, info):
         self.content = response.read()
         self.info = info
@@ -140,41 +150,39 @@ class GitHubResponse(object):
 
     def links(self):
         links = {}
-        if 'link' in self.info:
-            link_header = self.info['link']
+        if "link" in self.info:
+            link_header = self.info["link"]
             matches = re.findall('<([^>]+)>; rel="([^"]+)"', link_header)
             for url, rel in matches:
                 links[rel] = url
         return links
 
 
-class GitHubSession(object):
-    def __init__(self, module, token):
+class GitHubSession:
+    def __init__(self, module, token, api_url):
         self.module = module
         self.token = token
+        self.api_url = api_url.rstrip("/")
 
     def request(self, method, url, data=None):
         headers = {
-            'Authorization': 'token %s' % self.token,
-            'Content-Type': 'application/json',
-            'Accept': 'application/vnd.github.v3+json',
+            "Authorization": f"token {self.token}",
+            "Content-Type": "application/json",
+            "Accept": "application/vnd.github.v3+json",
         }
-        response, info = fetch_url(
-            self.module, url, method=method, data=data, headers=headers)
-        if not (200 <= info['status'] < 400):
-            self.module.fail_json(
-                msg=(" failed to send request %s to %s: %s"
-                     % (method, url, info['msg'])))
+        response, info = fetch_url(self.module, url, method=method, data=data, headers=headers)
+        if not (200 <= info["status"] < 400):
+            self.module.fail_json(msg=f" failed to send request {method} to {url}: {info['msg']}")
         return GitHubResponse(response, info)
 
 
 def get_all_keys(session):
-    url = API_BASE + '/user/keys'
+    url = f"{session.api_url}/user/keys"
     result = []
     while url:
-        r = session.request('GET', url)
+        r = session.request("GET", url)
         result.extend(r.json())
-        url = r.links().get('next')
+        url = r.links().get("next")
     return result
 
 
@@ -182,19 +190,18 @@ def create_key(session, name, pubkey, check_mode):
     if check_mode:
         now_t = now()
         return {
-            'id': 0,
-            'key': pubkey,
-            'title': name,
-            'url': 'http://example.com/CHECK_MODE_GITHUB_KEY',
-            'created_at': datetime.datetime.strftime(now_t, '%Y-%m-%dT%H:%M:%SZ'),
-            'read_only': False,
-            'verified': False
+            "id": 0,
+            "key": pubkey,
+            "title": name,
+            "url": "http://example.com/CHECK_MODE_GITHUB_KEY",
+            "created_at": datetime.datetime.strftime(now_t, "%Y-%m-%dT%H:%M:%SZ"),
+            "read_only": False,
+            "verified": False,
         }
     else:
         return session.request(
-            'POST',
-            API_BASE + '/user/keys',
-            data=json.dumps({'title': name, 'key': pubkey})).json()
+            "POST", f"{session.api_url}/user/keys", data=json.dumps({"title": name, "key": pubkey})
+        ).json()
 
 
 def delete_keys(session, to_delete, check_mode):
@@ -202,31 +209,30 @@ def delete_keys(session, to_delete, check_mode):
         return
 
     for key in to_delete:
-        session.request('DELETE', API_BASE + '/user/keys/%s' % key["id"])
+        session.request("DELETE", f"{session.api_url}/user/keys/{key['id']}")
 
 
 def ensure_key_absent(session, name, check_mode):
-    to_delete = [key for key in get_all_keys(session) if key['title'] == name]
+    to_delete = [key for key in get_all_keys(session) if key["title"] == name]
     delete_keys(session, to_delete, check_mode=check_mode)
 
-    return {'changed': bool(to_delete),
-            'deleted_keys': to_delete}
+    return {"changed": bool(to_delete), "deleted_keys": to_delete}
 
 
 def ensure_key_present(module, session, name, pubkey, force, check_mode):
     all_keys = get_all_keys(session)
-    matching_keys = [k for k in all_keys if k['title'] == name]
+    matching_keys = [k for k in all_keys if k["title"] == name]
     deleted_keys = []
 
-    new_signature = pubkey.split(' ')[1]
+    new_signature = pubkey.split(" ")[1]
     for key in all_keys:
-        existing_signature = key['key'].split(' ')[1]
-        if new_signature == existing_signature and key['title'] != name:
-            module.fail_json(msg=(
-                "another key with the same content is already registered "
-                "under the name |{0}|").format(key['title']))
+        existing_signature = key["key"].split(" ")[1]
+        if new_signature == existing_signature and key["title"] != name:
+            module.fail_json(
+                msg=f"another key with the same content is already registered under the name |{key['title']}|"
+            )
 
-    if matching_keys and force and matching_keys[0]['key'].split(' ')[1] != new_signature:
+    if matching_keys and force and matching_keys[0]["key"].split(" ")[1] != new_signature:
         delete_keys(session, matching_keys, check_mode=check_mode)
         (deleted_keys, matching_keys) = (matching_keys, [])
 
@@ -236,49 +242,50 @@ def ensure_key_present(module, session, name, pubkey, force, check_mode):
         key = matching_keys[0]
 
     return {
-        'changed': bool(deleted_keys or not matching_keys),
-        'deleted_keys': deleted_keys,
-        'matching_keys': matching_keys,
-        'key': key
+        "changed": bool(deleted_keys or not matching_keys),
+        "deleted_keys": deleted_keys,
+        "matching_keys": matching_keys,
+        "key": key,
     }
 
 
 def main():
     argument_spec = {
-        'token': {'required': True, 'no_log': True},
-        'name': {'required': True},
-        'pubkey': {},
-        'state': {'choices': ['present', 'absent'], 'default': 'present'},
-        'force': {'default': True, 'type': 'bool'},
+        "token": {"required": True, "no_log": True},
+        "name": {"required": True},
+        "pubkey": {},
+        "state": {"choices": ["present", "absent"], "default": "present"},
+        "force": {"default": True, "type": "bool"},
+        "api_url": {"default": "https://api.github.com", "type": "str"},
     }
     module = AnsibleModule(
         argument_spec=argument_spec,
         supports_check_mode=True,
     )
 
-    token = module.params['token']
-    name = module.params['name']
-    state = module.params['state']
-    force = module.params['force']
-    pubkey = module.params.get('pubkey')
+    token = module.params["token"]
+    name = module.params["name"]
+    state = module.params["state"]
+    force = module.params["force"]
+    pubkey = module.params.get("pubkey")
+    api_url = module.params.get("api_url")
 
     if pubkey:
-        pubkey_parts = pubkey.split(' ')
+        pubkey_parts = pubkey.split(" ")
         # Keys consist of a protocol, the key data, and an optional comment.
         if len(pubkey_parts) < 2:
             module.fail_json(msg='"pubkey" parameter has an invalid format')
-    elif state == 'present':
+    elif state == "present":
         module.fail_json(msg='"pubkey" is required when state=present')
 
-    session = GitHubSession(module, token)
-    if state == 'present':
-        result = ensure_key_present(module, session, name, pubkey, force=force,
-                                    check_mode=module.check_mode)
-    elif state == 'absent':
+    session = GitHubSession(module, token, api_url)
+    if state == "present":
+        result = ensure_key_present(module, session, name, pubkey, force=force, check_mode=module.check_mode)
+    elif state == "absent":
         result = ensure_key_absent(session, name, check_mode=module.check_mode)
 
     module.exit_json(**result)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
