@@ -2,12 +2,11 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 
 from ansible_collections.community.general.plugins.modules import django_check
-from .helper import Helper, RunCommandMock  # pylint: disable=unused-import
+from .uthelper import UTHelper, RunCommandMock
 
 
-Helper.from_module(django_check, __name__)
+UTHelper.from_module(django_check, __name__, mocks=[RunCommandMock])
