@@ -3,8 +3,7 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 import os
 import sys
@@ -14,7 +13,7 @@ import yaml
 import pytest
 
 
-class UTHelper(object):
+class UTHelper:
     TEST_SPEC_VALID_SECTIONS = ["anchors", "test_cases"]
 
     @staticmethod
@@ -31,14 +30,16 @@ class UTHelper(object):
     @staticmethod
     def from_module(ansible_module, test_module_name, mocks=None):
         test_module = sys.modules[test_module_name]
-        extensions = ['.yaml', '.yml']
+        extensions = [".yaml", ".yml"]
         for ext in extensions:
-            test_spec_filename = test_module.__file__.replace('.py', ext)
+            test_spec_filename = test_module.__file__.replace(".py", ext)
             if os.path.exists(test_spec_filename):
                 with open(test_spec_filename, "r") as test_spec_filehandle:
                     return UTHelper.from_file(ansible_module, test_module, test_spec_filehandle, mocks=mocks)
 
-        raise Exception("Cannot find test case file for {0} with one of the extensions: {1}".format(test_module.__file__, extensions))
+        raise Exception(
+            f"Cannot find test case file for {test_module.__file__} with one of the extensions: {extensions}"
+        )
 
     def add_func_to_test_module(self, name, func):
         setattr(self.test_module, name, func)
@@ -51,11 +52,11 @@ class UTHelper(object):
 
         spec_diff = set(test_spec.keys()) - set(self.TEST_SPEC_VALID_SECTIONS)
         if spec_diff:
-            raise ValueError("Test specification contain unknown keys: {0}".format(", ".join(spec_diff)))
+            raise ValueError(f"Test specification contain unknown keys: {', '.join(spec_diff)}")
 
         self.mocks_map = {m.name: m for m in mocks} if mocks else {}
 
-        for spec_test_case in test_spec['test_cases']:
+        for spec_test_case in test_spec["test_cases"]:
             tc = ModuleTestCase.make_test_case(spec_test_case, test_module, self.mocks_map)
             self.test_cases.append(tc)
             self.fixtures.update(tc.fixtures)
@@ -67,7 +68,7 @@ class UTHelper(object):
         return Runner(self.ansible_module.main)
 
     def set_test_func(self):
-        @pytest.mark.parametrize('test_case', self.test_cases, ids=[tc.id for tc in self.test_cases])
+        @pytest.mark.parametrize("test_case", self.test_cases, ids=[tc.id for tc in self.test_cases])
         @pytest.mark.usefixtures(*self.fixtures)
         def _test_module(mocker, capfd, patch_ansible_module_uthelper, test_case):
             """
@@ -126,22 +127,13 @@ class ModuleTestCase:
         self._fixtures = {}
 
     def __str__(self):
-        return "<ModuleTestCase: id={id} {input}{output}mocks={mocks} flags={flags}>".format(
-            id=self.id,
-            input="input " if self.input else "",
-            output="output " if self.output else "",
-            mocks="({0})".format(", ".join(self.mocks.keys())),
-            flags=self.flags
+        return (
+            f"<ModuleTestCase: id={self.id} {'input ' if self.input else ''}{'output ' if self.output else ''}"
+            f"mocks=({', '.join(self.mocks.keys())}) flags={self.flags}>"
         )
 
     def __repr__(self):
-        return "ModuleTestCase(id={id}, input={input}, output={output}, mocks={mocks}, flags={flags})".format(
-            id=self.id,
-            input=self.input,
-            output=self.output,
-            mocks=repr(self.mocks),
-            flags=self.flags
-        )
+        return f"ModuleTestCase(id={self.id}, input={self.input}, output={self.output}, mocks={self.mocks!r}, flags={self.flags})"
 
     @staticmethod
     def make_test_case(test_case_spec, test_module, mocks_map):
@@ -150,7 +142,7 @@ class ModuleTestCase:
             input=test_case_spec.get("input", {}),
             output=test_case_spec.get("output", {}),
             mocks=test_case_spec.get("mocks", {}),
-            flags=test_case_spec.get("flags", {})
+            flags=test_case_spec.get("flags", {}),
         )
         tc.build_mocks(mocks_map)
         return tc
@@ -160,7 +152,7 @@ class ModuleTestCase:
             try:
                 mock_class = mocks_map[mock_name]
             except KeyError:
-                raise Exception("Cannot find TestCaseMock class for: {0}".format(mock_name))
+                raise Exception(f"Cannot find TestCaseMock class for: {mock_name}")
             self.mocks[mock_name] = mock_class.build_mock(mock_spec)
 
             self._fixtures.update(self.mocks[mock_name].fixtures())
@@ -185,14 +177,15 @@ class ModuleTestCase:
             mock.setup(mocker)
 
     def check_testcase(self, results):
-        print("testcase =\n%s" % repr(self))
-        print("results =\n%s" % results)
-        if 'exception' in results:
-            print("exception = \n%s" % results["exception"])
+        print(f"testcase =\n{self!r}")
+        print(f"results =\n{results}")
+        if "exception" in results:
+            print(f"exception = \n{results['exception']}")
 
         for test_result in self.output:
-            assert results[test_result] == self.output[test_result], \
-                "'{0}': '{1}' != '{2}'".format(test_result, results[test_result], self.output[test_result])
+            assert results[test_result] == self.output[test_result], (
+                f"'{test_result}': '{results[test_result]}' != '{self.output[test_result]}'"
+            )
 
     def check_mocks(self, test_case, results):
         for mock in self.mocks.values():
@@ -204,6 +197,12 @@ class TestCaseMock:
     def build_mock(cls, mock_specs):
         return cls(mock_specs)
 
+    def __str__(self):
+        return f"<{self.__class__.__name__} specs={self.mock_specs}>"
+
+    def __repr__(self):
+        return f"{self.__class__.__name__}({self.mock_specs})"
+
     def __init__(self, mock_specs):
         self.mock_specs = mock_specs
 
@@ -220,24 +219,19 @@ class TestCaseMock:
 class RunCommandMock(TestCaseMock):
     name = "run_command"
 
-    def __str__(self):
-        return "<RunCommandMock specs={specs}>".format(specs=self.mock_specs)
-
-    def __repr__(self):
-        return "RunCommandMock({specs})".format(specs=self.mock_specs)
-
     def fixtures(self):
         @pytest.fixture
         def patch_bin(mocker):
             def mockie(self_, path, *args, **kwargs):
-                return "/testbin/{0}".format(path)
-            mocker.patch('ansible.module_utils.basic.AnsibleModule.get_bin_path', mockie)
+                return f"/testbin/{path}"
+
+            mocker.patch("ansible.module_utils.basic.AnsibleModule.get_bin_path", mockie)
 
         return {"patch_bin": patch_bin}
 
     def setup(self, mocker):
         def _results():
-            for result in [(x['rc'], x['out'], x['err']) for x in self.mock_specs]:
+            for result in [(x["rc"], x["out"], x["err"]) for x in self.mock_specs]:
                 yield result
             raise Exception("testcase has not enough run_command calls")
 
@@ -246,17 +240,21 @@ class RunCommandMock(TestCaseMock):
         def side_effect(self_, **kwargs):
             result = next(results)
             if kwargs.get("check_rc", False) and result[0] != 0:
-                raise Exception("rc = {0}".format(result[0]))
+                raise Exception(f"rc = {result[0]}")
             return result
 
-        self.mock_run_cmd = mocker.patch('ansible.module_utils.basic.AnsibleModule.run_command', side_effect=side_effect)
+        self.mock_run_cmd = mocker.patch(
+            "ansible.module_utils.basic.AnsibleModule.run_command", side_effect=side_effect
+        )
 
     def check(self, test_case, results):
         call_args_list = [(item[0][0], item[1]) for item in self.mock_run_cmd.call_args_list]
-        expected_call_args_list = [(item['command'], item.get('environ', {})) for item in self.mock_specs]
-        print("call args list =\n%s" % call_args_list)
-        print("expected args list =\n%s" % expected_call_args_list)
+        expected_call_args_list = [(item["command"], item.get("environ", {})) for item in self.mock_specs]
+        print(f"call args list =\n{call_args_list}")
+        print(f"expected args list =\n{expected_call_args_list}")
 
-        assert self.mock_run_cmd.call_count == len(self.mock_specs), "{0} != {1}".format(self.mock_run_cmd.call_count, len(self.mock_specs))
+        assert self.mock_run_cmd.call_count == len(self.mock_specs), (
+            f"{self.mock_run_cmd.call_count} != {len(self.mock_specs)}"
+        )
         if self.mock_run_cmd.call_count:
             assert call_args_list == expected_call_args_list
