@@ -3,8 +3,8 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 9.3.0
-# Copyright (C) 2024 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 9.12.1
+# Copyright (C) 2024-2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -26,18 +26,21 @@ options:
     description:
       - IP address or hostname of the iDRAC.
     type: str
+    aliases: [idrac_ip]
   username:
     description:
       - Username of the iDRAC. If the username is not provided, then
         the environment variable E(IDRAC_USERNAME) is used.
       - I(username) is required when I(state) is C(present).
     type: str
+    aliases: [idrac_user]
   password:
     description:
       - Password of the iDRAC. If the password is not provided, then
         the environment variable E(IDRAC_PASSWORD) is used.
       - I(password) is required when I(state) is C(present).
     type: str
+    aliases: [idrac_password]
   port:
     description:
       - Port of the iDRAC.
@@ -72,17 +75,18 @@ options:
      - Authentication token.
      - I(x_auth_token) is required when I(state) is C(absent).
     type: str
+    aliases: ['auth_token']
   session_id:
     description:
      - Session ID of the iDRAC.
      - I(session_id) is required when I(state) is C(absent).
-    type: int
-    aliases: ['auth_token']
+    type: str
 requirements:
   - "python >= 3.9.6"
 author:
   - "Rajshekar P(@rajshekarp87)"
   - "Kritika Bhateja (@Kritika-Bhateja-03)"
+  - "Saksham Nautiyal (@Saksham-Nautiyal)"
 notes:
     - Run this module from a system that has direct access to Dell iDRAC.
     - This module supports IPv4 and IPv6 addresses.
@@ -341,7 +345,7 @@ class DeleteSession(Session):
                     session_response = self.idrac.invoke_request(session_url + f"/{session_id}",
                                                                  "DELETE")
                     status = session_response.status_code
-                    if status == 200:
+                    if status in [200, 204]:
                         self.module.exit_json(msg=DELETE_SUCCESS_MSG, changed=True)
                 except HTTPError as err:
                     filter_err = remove_key(json.load(err), regex_pattern=ODATA_REGEX)
@@ -445,16 +449,18 @@ def get_argument_spec():
         A dictionary representing the argument specification.
     """
     return {
-        "hostname": {"type": "str"},
-        "username": {"type": "str", "fallback": (env_fallback, ['IDRAC_USERNAME'])},
-        "password": {"type": "str", "no_log": True, "fallback": (env_fallback, ['IDRAC_PASSWORD'])},
+        "hostname": {"type": "str", "aliases": ["idrac_ip"]},
+        "username": {"type": "str", "aliases": ["idrac_user"],
+                     "fallback": (env_fallback, ['IDRAC_USERNAME'])},
+        "password": {"type": "str", "aliases": ["idrac_password"], "no_log": True,
+                     "fallback": (env_fallback, ['IDRAC_PASSWORD'])},
         "port": {"type": "int", "default": 443},
         "validate_certs": {"type": "bool", "default": True},
         "ca_path": {"type": "path", "default": None},
         "timeout": {"type": "int", "default": 30},
+        "session_id": {"type": "str"},
         "state": {"type": 'str', "default": "present", "choices": ["present", "absent"]},
-        "x_auth_token": {"type": "str", "no_log": True, "aliases": ['auth_token']},
-        "session_id": {"type": "int"}
+        "x_auth_token": {"type": "str", "no_log": True, "aliases": ['auth_token']}
     }
 
 
