@@ -21,22 +21,23 @@ version_added: '3.0.0'
 author:
   - Hitachi Vantara LTD (@hitachi-vantara)
 requirements:
-  - python >= 3.8
+  - python >= 3.9
 attributes:
   check_mode:
     description: Determines if the module should run in check mode.
     support: none
 extends_documentation_fragment:
 - hitachivantara.vspone_block.common.gateway_note
+- hitachivantara.vspone_block.common.connection_with_type
 notes:
   - The input parameters C(consistency_group_id) and C(enable_quick_mode) were removed in version 3.4.0.
     These were deprecated due to internal API simplification and are no longer supported.
 options:
   state:
-    description: The level of the snapshot task. Choices are C(present), C(absent), C(split), C(sync), C(restore), C(clone).
+    description: The level of the snapshot task. Choices are C(present), C(absent), C(split), C(sync), C(restore), C(clone), C(defragment).
     type: str
     required: false
-    choices: ['present', 'absent', 'split', 'sync', 'restore', 'clone']
+    choices: ['present', 'absent', 'split', 'sync', 'restore', 'clone', 'defragment']
     default: 'present'
   storage_system_info:
     description: Information about the storage system. This field is an optional field.
@@ -47,33 +48,6 @@ options:
         description: The serial number of the storage system.
         type: str
         required: false
-  connection_info:
-    description: Information required to establish a connection to the storage system.
-    type: dict
-    required: true
-    suboptions:
-      address:
-        description: IP address or hostname of the storage system.
-        type: str
-        required: true
-      username:
-        description: Username for authentication. This is a required field.
-        type: str
-        required: false
-      password:
-        description: Password for authentication. This is a required field.
-        type: str
-        required: false
-      api_token:
-        description: This field is used to pass the value of the lock token to operate on locked resources.
-        type: str
-        required: false
-      connection_type:
-        description: Type of connection to the storage system.
-        type: str
-        required: false
-        choices: ['direct']
-        default: 'direct'
   spec:
     description: Specification for the snapshot task.
     type: dict
@@ -81,23 +55,67 @@ options:
     suboptions:
       primary_volume_id:
         description: ID of the primary volume.
-        type: int
+          Required for the Create a snapshot pair
+          /Create snapshot pair with a new consistency group
+          /Split a snapshot pair
+          /Resync a snapshot pair
+          /Create and auto-split a snapshot pair
+          /Restore a snapshot pair
+          /Create a snapshot pair using an existing consistency group
+          /Delete a snapshot pair
+          /Delete Thin Image pairs by snapshot tree
+          /Clone snapshot pair/Thin Image pair
+          /Create and clone snapshot pair
+          /Create and clone snapshot pair with copy speed and clones automation
+          /Create floating snapshot pair
+          /Assign floating snapshot pair
+          /Unassign floating snapshot pair
+          /Create Thin Image Advanced snapshot pair
+          /Set retention period of an existing snapshot pair
+          /Set retention period of snapshot pair after split
+          /Set retention period of snapshot pair with auto split
+          /Deleting garbage data of all Thin Image pairs in a snapshot tree tasks.
+        type: str
         required: true
       secondary_volume_id:
         description: Secondary volume id.
-        type: int
+          Required for the Create floating snapshot pair
+          /Assign floating snapshot pair
+          /Unassign floating snapshot pair tasks.
+          Optional for the Create Thin Image Advanced snapshot pair task.
+        type: str
         required: false
       pool_id:
         description: ID of the pool where the snapshot will be allocated.
+          Optional for the Create a snapshot pair
+          /Create snapshot pair with a new consistency group
+          /Create and auto-split a snapshot pair
+          /Create a snapshot pair using an existing consistency group
+          /Create and clone snapshot pair
+          /Create Thin Image Advanced snapshot pair
+          /Set retention period of snapshot pair with auto split tasks.
+          Required for the Create and clone snapshot pair with copy speed and clones automation
+          /Create floating snapshot pair tasks.
         type: int
         required: false
       snapshot_group_name:
         description: Name of the snapshot group.
+          Required for the Create a snapshot pair
+          /Create snapshot pair with a new consistency group
+          /Create and auto-split a snapshot pair
+          /Create a snapshot pair using an existing consistency group
+          /Create and clone snapshot pair
+          /Create and clone snapshot pair with copy speed and clones automation
+          /Create floating snapshot pair
+          /Create Thin Image Advanced snapshot pair
+          /Set retention period of snapshot pair with auto split tasks.
         type: str
         required: false
       is_data_reduction_force_copy:
         description: Specify whether to forcibly create a pair for a volume for which the capacity saving function is enabled.
           Default is True when capacity savings is not C(disabled).
+          Required for the Create a snapshot pair using an existing consistency group
+          /Create Thin Image Advanced snapshot pair tasks.
         required: false
         type: bool
       is_clone:
@@ -105,19 +123,33 @@ options:
           Specify whether to create a pair that has the clone attribute specified.
           If you specify true for this attribute, do not specify the auto_split attribute.
           When creating a Thin Image Advanced pair, you cannot specify true.
+          Required for the Create and clone snapshot pair
+          /Create and clone snapshot pair with copy speed and clones automation task.
         required: false
         type: bool
       can_cascade:
         description: Specify whether the pair can be cascaded.
           Default is True when capacity savings is not C(disabled), Lun may not required to add to any host group when is it true.
+          Required for the Create Thin Image Advanced snapshot pair task.
         required: false
         type: bool
       allocate_new_consistency_group:
         description: Specify whether to allocate a consistency group.
+          Required for the Create snapshot pair with a new consistency group task.
         required: false
         type: bool
       mirror_unit_id:
         description: ID of the mirror unit.
+          Required for the Split a snapshot pair
+          /Resync a snapshot pair
+          /Restore a snapshot pair
+          /Delete a snapshot pair
+          /Clone snapshot pair/Thin Image pair
+          /Unassign floating snapshot pair
+          /Set retention period of an existing snapshot pair
+          /Set retention period of snapshot pair after split tasks.
+          Optional for the Create floating snapshot pair
+          /Assign floating snapshot pair tasks.
         required: false
         type: int
       auto_split:
@@ -129,12 +161,16 @@ options:
           Specify the retention period for the snapshot in hours. This can be set when the snapshot status is PSUS.
           This attribute can be used when the storage system is VSP One B20.
           You can specify this attribute only if the auto_split attribute is set to true for new pair.
+          Required for the Set retention period of an existing snapshot pair
+          /Set retention period of snapshot pair after split
+          /Set retention period of snapshot pair with auto split tasks.
         required: false
         type: int
       copy_speed:
         description: >
           Specify the copy speed at which the created pair is to be cloned.
           You can specify this item when true is specified for both the is_clone attribute and the clones_automation attribute.
+          Required for the Create and clone snapshot pair with copy speed and clones automation task.
         required: false
         type: str
         choices: ["SLOW", "MEDIUM", "FAST"]
@@ -142,8 +178,23 @@ options:
         description: >
           Specify whether the pair is to be cloned after the pair is created.
           You can specify this item when true is specified for the is_clone attribute.
+          Required for the Create and clone snapshot pair with copy speed and clones automation task.
         required: false
         type: bool
+      should_delete_tree:
+        description: >
+          Specify whether to delete garbage data of all Thin Image pairs in a snapshot tree.
+          Required for the Delete Thin Image pairs by snapshot tree task.
+        required: false
+        type: bool
+      operation_type:
+        description: >
+          Specify the operation type for garbage data deletion.
+          This can be set when the should_delete_tree attribute is set to true.
+          Required for the Deleting garbage data of all Thin Image pairs in a snapshot tree task.
+        required: false
+        type: str
+        choices: ["start", "stop"]
 """
 
 EXAMPLES = """
@@ -319,95 +370,148 @@ EXAMPLES = """
       primary_volume_id: 100
       secondary_volume_id: -1
       mirror_unit_id: 1
+
+- name: Deleting garbage data of all Thin Image pairs in a snapshot tree
+  hitachivantara.vspone_block.vsp.hv_snapshot:
+    connection_info:
+      address: storage1.company.com
+      username: "username"
+      password: "password"
+    state: "defragment"
+    spec:
+      primary_volume_id: 100
+      operation_type: "start"
 """
 
 RETURN = """
-snapshots:
+snapshot:
   description: A list of snapshots gathered from the storage system.
   returned: always
   type: list
   elements: dict
   contains:
-    storage_serial_number:
-      description: Serial number of the storage system.
+    can_cascade:
+      description: Indicates if the snapshot can be cascaded.
+      type: bool
+      sample: true
+    concordance_rate:
+      description: Concordance rate of the snapshot operation.
       type: int
-      sample: 810050
-    primary_volume_id:
-      description: ID of the primary volume.
-      type: int
-      sample: 1030
-    primary_hex_volume_id:
-      description: Hexadecimal ID of the primary volume.
-      type: str
-      sample: "00:04:06"
-    secondary_volume_id:
-      description: ID of the secondary volume.
-      type: int
-      sample: 1031
-    secondary_hex_volume_id:
-      description: Hexadecimal ID of the secondary volume.
-      type: str
-      sample: "00:04:07"
-    svol_access_mode:
-      description: Access mode of the secondary volume.
+      sample: 100
+    copy_pace_track_size:
+      description: Copy pace track size.
       type: str
       sample: ""
-    pool_id:
-      description: ID of the pool where the snapshot is allocated.
-      type: int
-      sample: 12
-    mirror_unit_id:
-      description: ID of the mirror unit.
-      type: int
-      sample: 3
     copy_rate:
       description: Copy rate of the snapshot.
       type: int
       sample: -1
-    copy_pace_track_size:
-      description: Copy pace track size.
+    is_clone:
+      description: Indicates if the snapshot is a clone.
+      type: bool
+      sample: false
+    is_cloned:
+      description: Indicates if the snapshot has been cloned.
+      type: bool
+      sample: false
+    is_consistency_group:
+      description: Indicates if the snapshot is part of a consistency group.
+      type: bool
+      sample: true
+    is_data_reduction_force_copy:
+      description: Indicates if data reduction force copy is enabled.
+      type: bool
+      sample: true
+    is_redirect_on_write:
+      description: Indicates if redirect-on-write is enabled.
+      type: bool
+      sample: true
+    is_snapshot_data_read_only:
+      description: Indicates if the snapshot data is read-only.
+      type: bool
+      sample: null
+    is_written_in_svol:
+      description: Indicates if data is written in the secondary volume.
+      type: bool
+      sample: false
+    mirror_unit_id:
+      description: ID of the mirror unit.
+      type: int
+      sample: 3
+    pool_id:
+      description: ID of the pool where the snapshot is allocated.
+      type: int
+      sample: 1
+    primary_hex_volume_id:
+      description: Hexadecimal ID of the primary volume.
+      type: str
+      sample: "00:00:A8"
+    primary_volume_id:
+      description: ID of the primary volume.
+      type: int
+      sample: 168
+    progress_rate:
+      description: Progress rate of the snapshot operation.
+      type: int
+      sample: -1
+    pvol_host_groups:
+      description: List of host groups for the primary volume.
+      type: list
+      elements: str
+      sample: []
+    pvol_nvm_subsystem_name:
+      description: NVM subsystem name for the primary volume.
+      type: str
+      sample: ""
+    pvol_processing_status:
+      description: Processing status of the primary volume.
+      type: str
+      sample: "N"
+    retention_period_in_hours:
+      description: Retention period of the snapshot.
+      type: int
+      sample: -1
+    secondary_hex_volume_id:
+      description: Hexadecimal ID of the secondary volume.
+      type: str
+      sample: "00:00:CD"
+    secondary_volume_id:
+      description: ID of the secondary volume.
+      type: int
+      sample: 205
+    snapshot_group_name:
+      description: Name of the snapshot group.
+      type: str
+      sample: "snewar-tia-grp-02"
+    snapshot_id:
+      description: ID of the snapshot.
+      type: str
+      sample: "168,3"
+    split_time:
+      description: Time when the snapshot was split.
       type: str
       sample: ""
     status:
       description: Status of the snapshot.
       type: str
-      sample: "PAIR"
+      sample: "PFUL"
+    svol_host_groups:
+      description: List of host groups for the secondary volume.
+      type: list
+      elements: str
+      sample: []
+    svol_nvm_subsystem_name:
+      description: NVM subsystem name for the secondary volume.
+      type: str
+      sample: ""
+    svol_processing_status:
+      description: Processing status of the secondary volume.
+      type: str
+      sample: ""
     type:
       description: Type of the snapshot.
       type: str
-      sample: ""
-    snapshot_id:
-      description: ID of the snapshot.
-      type: str
-      sample: "1030,3"
-    is_consistency_group:
-      description: Indicates if the snapshot is part of a consistency group.
-      type: bool
-      sample: true
-    primary_or_secondary:
-      description: Indicates if the volume is primary or secondary.
-      type: str
-      sample: "P-VOL"
-    snapshot_group_name:
-      description: Name of the snapshot group.
-      type: str
-      sample: "NewNameSPG"
-    can_cascade:
-      description: Indicates if the snapshot can be cascaded.
-      type: bool
-      sample: true
-    retention_period_in_hours:
-      description: Retention period of the snapshot.
-      type: int
-      sample: 60
-    progress_rate:
-      description: Progress rate of the snapshot operation.
-      type: int
-      sample: 90
-    concordance_rate:
-      description: Concordance rate of the snapshot operation.
-      type: int
-      sample: 100
+      sample: "CASCADE"
 """
 
 
@@ -463,15 +567,21 @@ class VSPHtiSnapshotManager:
 
             snapshot_data = self.reconcile_snapshot()
             operation = operation_constants(self.module.params["state"])
-            msg = (
-                f"Snapshot {operation} successfully"
-                if not isinstance(snapshot_data, str)
-                else snapshot_data
-            )
+            msg = ""
+            if operation == "defragmented" and self.spec.operation_type == "start":
+                msg = "Started deleting garbage data of all Thin Image pairs in a snapshot tree"
+            elif operation == "defragmented" and self.spec.operation_type == "stop":
+                msg = "Stopped deleting garbage data of all Thin Image pairs in a snapshot tree"
+            else:
+                msg = (
+                    f"Snapshot {operation} successfully"
+                    if not isinstance(snapshot_data, str)
+                    else snapshot_data
+                )
             resp = {
                 "changed": self.connection_info.changed,
                 "snapshot_data": (
-                    snapshot_data if isinstance(snapshot_data, dict) else None
+                    snapshot_data if isinstance(snapshot_data, dict) else ""
                 ),
                 "msg": msg,
             }
